# Copyright 1999-2013 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI=5

DESCRIPTION="Downloads and installs third-party clamav signatures"
HOMEPAGE="http://sourceforge.net/projects/unofficial-sigs"
SRC_URI="mirror://sourceforge/unofficial-sigs/${P}.tar.gz"

LICENSE="BSD"
SLOT="0"
KEYWORDS="~amd64"
IUSE=""

DEPEND="app-antivirus/clamav"

# The script relies on either net-misc/socat, or Perl's
# IO::Socket::UNIX. We already depend on Perl, and Gentoo's Perl ships
# with IO::Socket::UNIX, so we can leave out net-misc/socat here.
RDEPEND="${DEPEND}
	app-crypt/gnupg
	dev-lang/perl
	net-dns/bind-tools
	net-misc/curl"

src_compile() {
	# First, fix the paths contained in the configuration file.
	local pid_default="/var/run/clamd.pid"
	local pid_gentoo="/run/clamav/clamd.pid"
	local socket_default="/var/run/clamd.socket"
	local socket_gentoo="/run/clamav/clamd.sock"

	sed -i  -e '$a\pkg_mgr="emerge"' \
		-e "\$a\\pkg_rm=\"emerge -C ${PN}\"" \
		-e "s~${socket_default}~${socket_gentoo}~" \
		-e "s~${pid_default}~${pid_gentoo}~" \
		"${PN}.conf" \
		|| die "failed to update paths in the ${PN}.conf file"

	# Now, change the script's working directory to point to
	# /var/lib/${PN}. We'll need to make this writable by the clamav
	# user during src_install.
	sed -i  -e "s~/usr/unofficial-dbs~/var/lib/${PN}~" "${PN}.conf" \
		|| die 'failed to update the work_dir variable'
}

src_install() {
	dosbin "${PN}.sh"

	# We set the script's working directory to /var/lib/${PN} in
	# src_compile, so make sure that the permissions are set correctly
	# here. By default, it runs as clamav/clamav.
	diropts -m 0755 -o clamav -g clamav
	dodir "/var/lib/${PN}"

	insinto /etc/logrotate.d
	doins "${PN}-logrotate"

	insinto /etc
	doins "${PN}.conf"

	doman "${PN}.8"
	dodoc CHANGELOG INSTALL README
}

pkg_postinst() {
	elog "You will need to set up your /etc/${PN}.conf file."
	elog "For details, please see the ${PN}(8) manual page."
	elog ""
	elog "Don't forget to set user_configuration_complete=\"yes\"."
	elog ""
	elog "An up-to-date description of the available SaneSecurity"
	elog "databases is available at,"
	elog ""
	elog "  http://sanesecurity.com/usage/signatures/"
	elog ""
}
